// Stepper - Version: Latest
#include <Stepper.h>

//Declare RemoteXY functions
#define REMOTEXY_MODE__SOFTSERIAL

#include <SoftwareSerial.h>
#include <RemoteXY.h>

//Declare pin functions on Redboard
#define stp 2
#define dir 3
#define MS1 4
#define MS2 5
#define EN  6



// RemoteXY connection settings
#define REMOTEXY_SERIAL_RX 8
#define REMOTEXY_SERIAL_TX 9
#define REMOTEXY_SERIAL_SPEED 9600

// RemoteXY configurate
#pragma pack(push, 1)
uint8_t RemoteXY_CONF[] =
{ 255, 2, 0, 11, 0, 28, 0, 8, 13, 0,
  4, 0, 10, 13, 7, 18, 2, 26, 4, 0,
  27, 13, 7, 18, 2, 26, 67, 4, 3, 56,
  20, 5, 2, 26, 11
};

// this structure defines all the variables of your control interface
struct {

  // input variable
  int8_t slider_1; // =0..100 slider position
  int8_t slider_2; // =0..100 slider position

  // output variable
  char text_1[11];  // string UTF8 end zero

  // other variable
  uint8_t connect_flag;  // =1 if wire connected, else =0

} RemoteXY;
#pragma pack(pop)

#define PIN_SWITCH_1 13

//Declare variables for functions
char user_input;
int x;
int y;
int state;
int fsrPin = A0;
int fsrReading;
int currentPressure;
int pressureDifference;
int steps = 0;
int increment = 0;
int remoteSteps = 0;

void setup() {
  RemoteXY_Init ();
  pinMode(stp, OUTPUT);
  pinMode(dir, OUTPUT);
  pinMode(MS1, OUTPUT);
  pinMode(MS2, OUTPUT);
  pinMode(EN, OUTPUT);
  resetEDPins(); //Set step, direction, microstep and enable pins to default states
  Serial.begin(9600); //Open Serial connection for debugging
  Serial.println("Begin motor control");
  Serial.println();
  currentPressure = 0;

  pinMode (PIN_SWITCH_1, OUTPUT);
}

//Main loop
void loop() {
  RemoteXY_Handler ();

  //digitalWrite(PIN_SWITCH_1, (RemoteXY.slider_1 == 0) ? LOW : HIGH); //this will be analogwrite using switch_1; instead of writing to pinswitch1, just write to the motor driver instead. Instead of using steps>0 or steps<0, have a value of 0 go backward, value of 100 go forward
  //value of 50 is in the middle. for every movement of the slider in a direction, tilt or raise chair more or less. <-- how to do this?
  remoteSteps = RemoteXY.slider_1;
  if(RemoteXY.slider_1 >50)
  {
  digitalWrite(dir, LOW);
  for (x = 1; x < remoteSteps * 100; x++)
  {
    digitalWrite(stp, HIGH);
    delay(1);
    digitalWrite(stp, LOW);
    delay(1);
  }
    
  }
  else if(RemoteXY.slider_1 < 50)
  {
    digitalWrite(dir, HIGH);
  for (x = 1; x < remoteSteps * 100; x++)
  {
    digitalWrite(stp, HIGH);
    delay(1);
    digitalWrite(stp, LOW);
    delay(1);
  }
  }
  //if(value > 50)
  //then set it to high, have a variable similar to steps
  //also remove functionality of the pressure sensor so it doesn't interfere
  //if *bluetooth connected
  fsrReading = analogRead(fsrPin);
  //Serial.println(fsrReading);//debugging

  digitalWrite(EN, LOW); //Pull enable pin low to allow motor control
  steps = 0;
  pressureDifference = fsrReading - currentPressure;
  increment = pressureDifference / fsrReading;
  if (abs(increment) > 0.1)
  {
    steps = round(pressureDifference * 12 / 1024); // 12 steps of the motor in 90 degrees, 1024 is max analog input, linear stepping
  }
 Serial.println(steps);
  Serial.println(pressureDifference);
  //Serial.println(bitRead(PORTD, 3));
  //Serial.println(digitalRead(3));

  if (steps > 0)
  {
    StepForwardVary();
  }
  else if (steps < 0)
  {
    StepBackwardVary();
  }


  /*if (fsrReading<100)
    {
     //StepForwardDefault();
    }
    else if(100<fsrReading<290)
    {
    ReverseStepDefault();
    }
    else if(300<fsrReading<790)
    {
    SmallStepMode();
    }
    else if(800<fsrReading<1000)
    {
    //ForwardBackwardStep();
    StepForwardDefault();
    } /*
    else
    {
    Serial.println("Invalid option entered.");
    } */
  resetEDPins();
  delay(1000);
  currentPressure = fsrReading;
}


//step forward (use if positive)

void StepForwardVary()
{
  digitalWrite(dir, LOW);
  for (x = 1; x < steps * 1000; x++)
  {
    digitalWrite(stp, HIGH);
    delay(1);
    digitalWrite(stp, LOW);
    delay(1);
  }
}

//step backward (use if negative)
void StepBackwardVary()
{
  digitalWrite(dir, HIGH);
  for (x = 1; x < abs(steps) * 1000; x++)
  {
    digitalWrite(stp, HIGH);
    delay(1);
    digitalWrite(stp, LOW);
    delay(1);
  }
}


//Reset Easy Driver pins to default states
void resetEDPins()
{
  digitalWrite(stp, LOW);
  digitalWrite(dir, LOW);
  digitalWrite(MS1, LOW);
  digitalWrite(MS2, LOW);
  digitalWrite(EN, HIGH);
}
